'''
# @affinidi/common-check-widget-backend-lib [![NPM](https://img.shields.io/npm/v/jsii-code-samples)](https://www.npmjs.com/package/@affinidi/common-check-widget-backend-lib) [![PyPI](https://img.shields.io/pypi/v/aws-jsiisamples.jsii-code-samples)](https://pypi.org/project/common-check-widget-backend-lib) [![Maven](https://img.shields.io/maven-central/v/software.aws.jsiisamples.jsii/jsii-code-samples)](https://search.maven.org/artifact/common.check.widget.backend.lib/backend-ib) [![NuGet](https://img.shields.io/nuget/v/AWSSamples.Jsii)](https://www.nuget.org/packages/CCW.Jsii%22)

> An common-check-widget-backend-lib package authored in TypeScript that gets published as GitHub packages for Node.js, Python etc

## License

This library is licensed under the MIT-0 License. See the LICENSE file.

## Documentations

https://common-check-widget-backend-lib.affinity-project.org/
'''
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from ._jsii import *

from .common_check_verify import CommonCheckVerify as _CommonCheckVerify_98e4d318


class CommonCheckWidget(
    metaclass=jsii.JSIIMeta,
    jsii_type="@affinidi/common-check-widget-backend-lib.CommonCheckWidget",
):
    def __init__(self, request_id: builtins.str) -> None:
        '''
        :param request_id: -
        '''
        jsii.create(CommonCheckWidget, self, [request_id])

    @jsii.member(jsii_name="verifyAsync")
    def verify_async(self, encryption_file: typing.Any) -> typing.Any:
        '''
        :param encryption_file: -
        '''
        return typing.cast(typing.Any, jsii.ainvoke(self, "verifyAsync", [encryption_file]))

    @jsii.member(jsii_name="verifyByPathAsync")
    def verify_by_path_async(self, encryption_file_path: builtins.str) -> typing.Any:
        '''
        :param encryption_file_path: -
        '''
        return typing.cast(typing.Any, jsii.ainvoke(self, "verifyByPathAsync", [encryption_file_path]))

    @jsii.member(jsii_name="verifyByPathWithCallback")
    def verify_by_path_with_callback(
        self,
        encryption_file_path: builtins.str,
        callback: typing.Any,
    ) -> None:
        '''
        :param encryption_file_path: -
        :param callback: -
        '''
        return typing.cast(None, jsii.invoke(self, "verifyByPathWithCallback", [encryption_file_path, callback]))

    @jsii.member(jsii_name="verifyWithCallback")
    def verify_with_callback(
        self,
        encryption_file: typing.Any,
        callback: typing.Any,
    ) -> None:
        '''
        :param encryption_file: -
        :param callback: -
        '''
        return typing.cast(None, jsii.invoke(self, "verifyWithCallback", [encryption_file, callback]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="commonCheckVerify")
    def common_check_verify(self) -> _CommonCheckVerify_98e4d318:
        return typing.cast(_CommonCheckVerify_98e4d318, jsii.get(self, "commonCheckVerify"))

    @common_check_verify.setter
    def common_check_verify(self, value: _CommonCheckVerify_98e4d318) -> None:
        jsii.set(self, "commonCheckVerify", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="requestID")
    def request_id(self) -> typing.Any:
        return typing.cast(typing.Any, jsii.get(self, "requestID"))

    @request_id.setter
    def request_id(self, value: typing.Any) -> None:
        jsii.set(self, "requestID", value)


__all__ = [
    "CommonCheckWidget",
]

publication.publish()



import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from ..._jsii import *


class EndpointServiceBase(
    metaclass=jsii.JSIIAbstractClass,
    jsii_type="@affinidi/common-check-widget-backend-lib.commonCheckVerify.endpointServiceBase.EndpointServiceBase",
):
    def __init__(
        self,
        api_endpoint: builtins.str,
        api_key: builtins.str,
        error_code: builtins.str,
        request_id: builtins.str,
    ) -> None:
        '''
        :param api_endpoint: -
        :param api_key: -
        :param error_code: -
        :param request_id: -
        '''
        jsii.create(EndpointServiceBase, self, [api_endpoint, api_key, error_code, request_id])

    @jsii.member(jsii_name="callAPIEndpoint")
    def call_api_endpoint(self) -> typing.Any:
        return typing.cast(typing.Any, jsii.ainvoke(self, "callAPIEndpoint", []))

    @jsii.member(jsii_name="fillOptions")
    def fill_options(self, options: typing.Any) -> None:
        '''
        :param options: -
        '''
        return typing.cast(None, jsii.invoke(self, "fillOptions", [options]))

    @jsii.member(jsii_name="getErrorMessage")
    def get_error_message(self, error_obj: typing.Any = None) -> typing.Any:
        '''
        :param error_obj: -
        '''
        return typing.cast(typing.Any, jsii.invoke(self, "getErrorMessage", [error_obj]))

    @jsii.member(jsii_name="retrieveApiKey")
    def retrieve_api_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.invoke(self, "retrieveApiKey", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="apiEndpoint")
    def api_endpoint(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "apiEndpoint"))

    @api_endpoint.setter
    def api_endpoint(self, value: builtins.str) -> None:
        jsii.set(self, "apiEndpoint", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="apiKey")
    def api_key(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "apiKey"))

    @api_key.setter
    def api_key(self, value: builtins.str) -> None:
        jsii.set(self, "apiKey", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorCode")
    def error_code(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "errorCode"))

    @error_code.setter
    def error_code(self, value: builtins.str) -> None:
        jsii.set(self, "errorCode", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errors")
    def errors(self) -> typing.Any:
        return typing.cast(typing.Any, jsii.get(self, "errors"))

    @errors.setter
    def errors(self, value: typing.Any) -> None:
        jsii.set(self, "errors", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="options")
    def options(self) -> typing.Any:
        return typing.cast(typing.Any, jsii.get(self, "options"))

    @options.setter
    def options(self, value: typing.Any) -> None:
        jsii.set(self, "options", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="requestID")
    def request_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "requestID"))

    @request_id.setter
    def request_id(self, value: builtins.str) -> None:
        jsii.set(self, "requestID", value)


class _EndpointServiceBaseProxy(EndpointServiceBase):
    pass

# Adding a "__jsii_proxy_class__(): typing.Type" function to the abstract class
typing.cast(typing.Any, EndpointServiceBase).__jsii_proxy_class__ = lambda : _EndpointServiceBaseProxy


__all__ = [
    "EndpointServiceBase",
]

publication.publish()



import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from .._jsii import *

from .endpoint_service_base import EndpointServiceBase as _EndpointServiceBase_6aa74fa3


class CommonCheckVerify(
    _EndpointServiceBase_6aa74fa3,
    metaclass=jsii.JSIIMeta,
    jsii_type="@affinidi/common-check-widget-backend-lib.commonCheckVerify.CommonCheckVerify",
):
    def __init__(self, request_id: builtins.str) -> None:
        '''
        :param request_id: -
        '''
        jsii.create(CommonCheckVerify, self, [request_id])

    @jsii.member(jsii_name="fillEncryptionFile")
    def fill_encryption_file(self, encryption_file: typing.Any) -> None:
        '''
        :param encryption_file: -
        '''
        return typing.cast(None, jsii.invoke(self, "fillEncryptionFile", [encryption_file]))

    @jsii.member(jsii_name="generateOptions")
    def generate_options(self) -> typing.Any:
        return typing.cast(typing.Any, jsii.ainvoke(self, "generateOptions", []))

    @jsii.member(jsii_name="generateResponse")
    def generate_response(self) -> typing.Any:
        return typing.cast(typing.Any, jsii.ainvoke(self, "generateResponse", []))

    @jsii.member(jsii_name="generateToken")
    def generate_token(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.ainvoke(self, "generateToken", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="encryptionFile")
    def encryption_file(self) -> typing.Any:
        return typing.cast(typing.Any, jsii.get(self, "encryptionFile"))

    @encryption_file.setter
    def encryption_file(self, value: typing.Any) -> None:
        jsii.set(self, "encryptionFile", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="options")
    def options(self) -> typing.Any:
        return typing.cast(typing.Any, jsii.get(self, "options"))

    @options.setter
    def options(self, value: typing.Any) -> None:
        jsii.set(self, "options", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="privateKeyFileName")
    def private_key_file_name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "privateKeyFileName"))

    @private_key_file_name.setter
    def private_key_file_name(self, value: builtins.str) -> None:
        jsii.set(self, "privateKeyFileName", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="requestID")
    def request_id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "requestID"))

    @request_id.setter
    def request_id(self, value: builtins.str) -> None:
        jsii.set(self, "requestID", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secretPassphrase")
    def secret_passphrase(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "secretPassphrase"))

    @secret_passphrase.setter
    def secret_passphrase(self, value: builtins.str) -> None:
        jsii.set(self, "secretPassphrase", value)


__all__ = [
    "CommonCheckVerify",
]

publication.publish()
